==> 0.0.13.tar.gz: lib/antsomi_platform_interface.dart <==
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import 'antsomi_method_channel.dart';

import 'package:antsomisdk/modify_action.dart';

import 'catalog.dart';
import 'cdp_event.dart';
import 'inbox_items.dart';

abstract class AntsomiPlatform extends PlatformInterface {
  /// Constructs a AntsomiPlatform.
  AntsomiPlatform() : super(token: _token);

  static final Object _token = Object();

  static AntsomiPlatform _instance = MethodChannelAntsomi();

  late final void Function(InboxItem) callback;

  late final void Function(String urlString) deepLinkHandler;

  void Function()? setDefaultAction;

  /// The default instance of [AntsomiPlatform] to use.
  ///
  /// Defaults to [MethodChannelAntsomi].
  static AntsomiPlatform get instance => _instance;

  /// Platform-specific implementations should set this with their own
  /// platform-specific class that extends [AntsomiPlatform] when
  /// they register themselves.
  static set instance(AntsomiPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  Future<String?> getPlatformVersion() {
    throw UnimplementedError('platformVersion() has not been implemented.');
  }

  Future setCustomerProperties(
      {required String customerId, Map<String, String>? customerProperties}) {
    throw UnimplementedError('platformVersion() has not been implemented.');
  }

  void trackScreen(
      {required String name, String title = "", String type = ""}) {
    throw UnimplementedError('config() has not been implemented.');
  }

  Future<bool?> config(
      {required String portalId,
      required String propsId,
      required String appGroupId,
      required String applicationId}) {
    throw UnimplementedError('config() has not been implemented.');
  }

  Future appInboxInit(
      {required String destinationId, required String audienceType}) {
    throw UnimplementedError('appInboxInit() has not been implemented.');
  }

  void parseDeepLink(Uri url) {
    throw UnimplementedError('appInboxInit() has not been implemented.');
  }

  Future<List<InboxItem>> getMessage(
      {List<String>? catalogId = const [], required int page}) {
    throw UnimplementedError('getMessage() has not been implemented.');
  }

  Future<String?> getUID() {
    throw UnimplementedError('getUID() has not been implemented.');
  }

  Future<String?> getCustomerId() {
    throw UnimplementedError('getCustomerId() has not been implemented.');
  }

  Future<String?> getDeviceId() {
    throw UnimplementedError('getDeviceId() has not been implemented.');
  }

  Future<String?> getPropsId() {
    throw UnimplementedError('getPropsId() has not been implemented.');
  }

  Future<String?> getPortalId() {
    throw UnimplementedError('getPortalId() has not been implemented.');
  }

  Future<int?> getUnreadMessageCount() {
    throw UnimplementedError(
        'getUnreadMessageCount() has not been implemented.');
  }

  Future<List<Catalog>> getAllLabels() {
    throw UnimplementedError('getAllLabels() has not been implemented.');
  }

  Future<Map<String, String>> getMessageById({required String messageId}) {
    throw UnimplementedError('getMessageById() has not been implemented.');
  }

  Future<String?> getContext() {
    throw UnimplementedError('not been implemented.');
  }

  void onNewMessageReceived(void Function(InboxItem callbackValue)? callback) {
    throw UnimplementedError('newMessageReceived() has not been implemented.');
  }

  void configureChannel() {
    throw UnimplementedError('configureChannel() has not been implemented.');
  }

  void modifyAction({required String messageId, required ActionType action}) {
    throw UnimplementedError('modifiAction() has not been implemented.');
  }

  void track({required CDPEvent event}) {
    throw UnimplementedError('track() has not been implemented.');
  }

  void setPageLimit({required int limit}) {
    throw UnimplementedError('setPageLimit() has not been implemented.');
  }
}

==> 0.0.15.tar.gz: lib/antsomi_platform_interface.dart <==
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import 'antsomi_method_channel.dart';

import 'package:antsomisdk/modify_action.dart';

import 'catalog.dart';
import 'cdp_event.dart';
import 'inbox_items.dart';

abstract class AntsomiPlatform extends PlatformInterface {
  /// Constructs a AntsomiPlatform.
  AntsomiPlatform() : super(token: _token);

  static final Object _token = Object();

  static AntsomiPlatform _instance = MethodChannelAntsomi();

  late final void Function(InboxItem) callback;

  late final void Function(String urlString) deepLinkHandler;

  void Function()? setDefaultAction;

  /// The default instance of [AntsomiPlatform] to use.
  ///
  /// Defaults to [MethodChannelAntsomi].
  static AntsomiPlatform get instance => _instance;

  /// Platform-specific implementations should set this with their own
  /// platform-specific class that extends [AntsomiPlatform] when
  /// they register themselves.
  static set instance(AntsomiPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  Future<String?> getPlatformVersion() {
    throw UnimplementedError('platformVersion() has not been implemented.');
  }

  Future setCustomerProperties(
      {required String customerId, Map<String, String>? customerProperties}) {
    throw UnimplementedError('platformVersion() has not been implemented.');
  }

  void trackScreen(
      {required String name, String title = "", String type = ""}) {
    throw UnimplementedError('config() has not been implemented.');
  }

  Future<bool?> config(
      {required String portalId,
      required String propsId,
      required String appGroupId,
      required String applicationId}) {
    throw UnimplementedError('config() has not been implemented.');
  }

  Future appInboxInit(
      {required String destinationId, required String audienceType}) {
    throw UnimplementedError('appInboxInit() has not been implemented.');
  }

  void parseDeepLink(Uri url) {
    throw UnimplementedError('appInboxInit() has not been implemented.');
  }

  Future<List<InboxItem>> getMessage(
      {List<String>? catalogId = const [], required int page}) {
    throw UnimplementedError('getMessage() has not been implemented.');
  }

  Future<String?> getUID() {
    throw UnimplementedError('getUID() has not been implemented.');
  }

  Future<String?> getCustomerId() {
    throw UnimplementedError('getCustomerId() has not been implemented.');
  }

  Future<String?> getDeviceId() {
    throw UnimplementedError('getDeviceId() has not been implemented.');
  }

  Future<String?> getPropsId() {
    throw UnimplementedError('getPropsId() has not been implemented.');
  }

  Future<String?> getPortalId() {
    throw UnimplementedError('getPortalId() has not been implemented.');
  }

  Future<int?> getUnreadMessageCount() {
    throw UnimplementedError(
        'getUnreadMessageCount() has not been implemented.');
  }

  Future<List<Catalog>> getAllLabels() {
    throw UnimplementedError('getAllLabels() has not been implemented.');
  }

  Future<Map<String, String>> getMessageById({required String messageId}) {
    throw UnimplementedError('getMessageById() has not been implemented.');
  }

  Future<String?> getContext() {
    throw UnimplementedError('not been implemented.');
  }

  void onNewMessageReceived(void Function(InboxItem callbackValue)? callback) {
    throw UnimplementedError('newMessageReceived() has not been implemented.');
  }

  void configureChannel() {
    throw UnimplementedError('configureChannel() has not been implemented.');
  }

  void modifyAction({required List<String> messageId, required int action}) {
    throw UnimplementedError('modifiAction() has not been implemented.');
  }

  void track({required CDPEvent event}) {
    throw UnimplementedError('track() has not been implemented.');
  }

  void setPageLimit({required int limit}) {
    throw UnimplementedError('setPageLimit() has not been implemented.');
  }
}
